#!/bin/sh
#
# Create initramfs for Linux kernel as a CPIO archive.
#
# ${LINUXSRC} must point to the Linux kernel source directory.
# ${SYSROOT}  must point to to the directory holding the root filesystem.
# sysroot.cpio will be created in the current directory.
#

set -e

if [ ! -f "${LINUXSRC}/scripts/gen_initramfs_list.sh" ]; then
  echo '${LINUXSRC} must point to the Linux kernel source' >&2
  exit 1
fi

if [ ! -f "${SYSROOT}/bin/busybox" ]; then
  echo '${SYSROOT} must point to the directory holding the root filesystem' >&2
  exit 1
fi

make -C "${LINUXSRC}/usr" gen_init_cpio

uid=`id -u`
gid=`id -g`
sh "${LINUXSRC}/scripts/gen_initramfs_list.sh" -u ${uid} -g ${gid} "${SYSROOT}" | sed -e 's/^file \(\/bin\/busybox .*\) 755 0 0/file \1 4755 0 0/' > sysroot.files

cat <<EOF >> sysroot.files
dir /dev 755 0 0
dir /proc 755 0 0
dir /sys 755 0 0
dir /tmp 755 0 0
dir /var 755 0 0
dir /root 700 0 0
nod /dev/null 666 0 0 c 1 3
nod /dev/tty1 600 0 0 c 4 1
nod /dev/ttyS0 600 0 0 c 4 64
nod /dev/tty 666 0 0 c 5 0
nod /dev/console 600 0 0 c 5 1
EOF

"${LINUXSRC}/usr/gen_init_cpio" sysroot.files > sysroot.cpio
ls -l sysroot.cpio

